MatchMaker.match_to() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMaker.match_to()

MatchMaker.match_to(name: str) → Group

  Matches participants to a group based on a specific spec.

  Parameters

    name (str) – Name of the spec that should be used.

  Raises

    NoMatch – If a single matching effort was unsuccesful. This exception gets handled by `WaitingPage` and is part of a normal matching process.

  Returns

    If matching was successful.

  Return type

    Group